////////////////////////////////////////////////////////////////////////////////
// TWallPaper component
//
// Controls that allows to display a bitmap as a wall paper (like in Windows)
//
// by Alan GARNY
//    gry@physiol.ox.ac.uk
//    http://pc-heartbreak.physiol.ox.ac.uk/
//
//  Copyright 1997-98
////////////////////////////////////////////////////////////////////////////////

#ifndef WallpaperH
#define WallpaperH

////////////////////////////////////////////////////////////////////////////////

enum TWallPaperDisplay {diTile, diCenter};

////////////////////////////////////////////////////////////////////////////////

#if (__BORLANDC__ >= 0x0530)   // i.e. NOT BCB 1.0
class PACKAGE TWallPaper: public TCustomPanel
#else
class TWallPaper: public TCustomPanel
#endif
{
   private:
      // Private representation of published properties

      TPanelBevel FBevel;
      TBevelWidth FBevelWidth;
      TWallPaperDisplay FDisplay;
      Graphics::TBitmap *FBitmap;

      // Methods to modify the different published properties

      void __fastcall SetBevel(const TPanelBevel aValue);
      void __fastcall SetBevelWidth(const TBevelWidth aValue);
      void __fastcall SetDisplay(const TWallPaperDisplay aValue);
      void __fastcall SetBitmap(Graphics::TBitmap *aValue);

   protected:
      // Method to draw the control

      virtual void __fastcall Paint();

   public:
      // Constructor & Destructor

      virtual __fastcall TWallPaper(TComponent *aOwner);
      virtual __fastcall ~TWallPaper();

   __published:
      // Published properties

      __property Align;
      __property TPanelBevel Bevel = {read=FBevel, write=SetBevel, default=bvNone};
      __property TBevelWidth BevelWidth = {read=FBevelWidth, write=SetBevelWidth, default=1};
      __property Graphics::TBitmap *Bitmap = {read=FBitmap, write=SetBitmap, nodefault};
      __property Color;
      __property TWallPaperDisplay Display = {read=FDisplay, write=SetDisplay, default=diTile};
      __property DragCursor;
      __property DragMode;
      __property Enabled;
      __property ParentColor;
      __property ParentShowHint;
      __property PopupMenu;
      __property ShowHint;
      __property Visible;

      // Available events

      __property OnClick;
      __property OnDblClick;
      __property OnDragDrop;
      __property OnDragOver;
      __property OnEndDrag;
      __property OnEnter;
      __property OnExit;
      __property OnMouseDown;
      __property OnMouseMove;
      __property OnMouseUp;
      __property OnResize;
      __property OnStartDrag;
};

////////////////////////////////////////////////////////////////////////////////

#endif

// End of file
////////////////////////////////////////////////////////////////////////////////
